@@ -35,6 +35,16 @@
 #    define _ONEDPL_SPECIALIZE_FOR(TYPE, ...) TYPE<__VA_ARGS__>
 #endif
 
+// namespaces in this file:
+//      namespace oneapi::dpl::__internal
+//      namespace oneapi::dpl::__internal::__ranges
+//      namespace oneapi::dpl::ranges::__internal
+//      namespace oneapi::dpl::experimental::ranges::__internal
+//      namespace oneapi::dpl::__par_backend_hetero
+//      namespace oneapi::dpl::unseq_backend
+//      namespace oneapi::dpl::internal
+//      namespace oneapi::dpl
+
 namespace oneapi::dpl::__internal
 {
 
@@ -94,15 +104,56 @@ struct __is_heap_check;
 template <typename _Predicate, typename _ValueType>
 struct __create_mask_unique_copy;
 
-template <class _Tag, typename _ExecutionPolicy, typename _Tp, typename>
+template <class _Tag, typename _Tp, typename>
 struct __brick_fill;
 
-template <class _Tag, typename _ExecutionPolicy, typename _Tp, typename>
+template <class _Tag, typename _Tp, typename>
 struct __brick_fill_n;
 
 template <typename... T>
 struct tuple;
 
+template <typename InputIterator, typename StrictWeakOrdering, typename _ValueType>
+struct __lower_bound_impl_fn;
+
+template <typename InputIterator, typename StrictWeakOrdering, typename _ValueType>
+struct __upper_bound_impl_fn;
+
+template <typename InputIterator, typename StrictWeakOrdering, typename _ValueType>
+struct __binary_search_impl_fn;
+
+#if _ONEDPL_CPP20_RANGES_PRESENT
+template <typename _T, typename _Proj>
+struct __count_fn_pred;
+#endif
+
+template <typename _ReduceValueType, typename _Compare>
+struct __pattern_min_element_reduce_fn;
+
+template <typename _Compare, typename _ReduceValueType>
+struct __pattern_minmax_element_reduce_fn;
+
+template <typename _Predicate>
+struct __pattern_count_transform_fn;
+
+template <typename _Predicate>
+struct __pattern_is_partitioned_transform_fn;
+
+template <typename _Compare, typename _ReduceValueType>
+struct __pattern_lexicographical_compare_transform_fn;
+
+template <typename _Tp>
+struct __pattern_search_n_fn;
+
+template <typename _BinaryPredicate>
+struct __parallel_reduce_by_segment_fallback_fn1;
+
+template <typename _BinaryPredicate>
+struct __parallel_reduce_by_segment_fallback_fn2;
+
+template <typename _Op, typename _It1ValueT, typename _It2ValueTRef>
+struct __pattern_adjacent_difference_op_caller_fn;
+
 } // namespace oneapi::dpl::__internal
 
 template <typename _Pred>
@@ -179,16 +230,16 @@ struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::
 {
 };
 
-template <class _Tag, typename _ExecutionPolicy, typename _Tp, typename _EnableIfPlaceholder>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__brick_fill, _Tag, _ExecutionPolicy,
-                                                       _Tp, _EnableIfPlaceholder)>
+template <class _Tag, typename _Tp, typename _EnableIfPlaceholder>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__brick_fill, _Tag, _Tp,
+                                                       _EnableIfPlaceholder)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Tp>
 {
 };
 
-template <class _Tag, typename _ExecutionPolicy, typename _Tp, typename _EnableIfPlaceholder>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__brick_fill_n, _Tag, _ExecutionPolicy,
-                                                       _Tp, _EnableIfPlaceholder)>
+template <class _Tag, typename _Tp, typename _EnableIfPlaceholder>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__brick_fill_n, _Tag, _Tp,
+                                                       _EnableIfPlaceholder)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Tp>
 {
 };
@@ -230,6 +281,136 @@ struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::
 {
 };
 
+template <typename InputIterator, typename StrictWeakOrdering, typename _ValueType>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__lower_bound_impl_fn, InputIterator,
+                                                       StrictWeakOrdering, _ValueType)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<InputIterator, StrictWeakOrdering, _ValueType>
+{
+};
+
+template <typename InputIterator, typename StrictWeakOrdering, typename _ValueType>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__upper_bound_impl_fn, InputIterator,
+                                                       StrictWeakOrdering, _ValueType)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<InputIterator, StrictWeakOrdering, _ValueType>
+{
+};
+
+template <typename InputIterator, typename StrictWeakOrdering, typename _ValueType>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__binary_search_impl_fn, InputIterator,
+                                                       StrictWeakOrdering, _ValueType)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<InputIterator, StrictWeakOrdering, _ValueType>
+{
+};
+
+#if _ONEDPL_CPP20_RANGES_PRESENT
+template <typename _T, typename _Proj>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__count_fn_pred, _T, _Proj)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_T, _Proj>
+{
+};
+#endif
+
+template <typename _ReduceValueType, typename _Compare>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__pattern_min_element_reduce_fn,
+                                                       _ReduceValueType, _Compare)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_ReduceValueType, _Compare>
+{
+};
+
+template <typename _Compare, typename _ReduceValueType>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__pattern_minmax_element_reduce_fn,
+                                                       _Compare, _ReduceValueType)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_Compare, _ReduceValueType>
+{
+};
+
+template <typename _Predicate>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__pattern_count_transform_fn,
+                                                       _Predicate)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_Predicate>
+{
+};
+
+template <typename _Predicate>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__pattern_is_partitioned_transform_fn,
+                                                       _Predicate)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_Predicate>
+{
+};
+
+template <typename _Compare, typename _ReduceValueType>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(
+    oneapi::dpl::__internal::__pattern_lexicographical_compare_transform_fn, _Compare, _ReduceValueType)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_Compare, _ReduceValueType>
+{
+};
+
+template <typename _Tp>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__pattern_search_n_fn, _Tp)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_Tp>
+{
+};
+
+template <typename _BinaryPredicate>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(
+    oneapi::dpl::__internal::__parallel_reduce_by_segment_fallback_fn1, _BinaryPredicate)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_BinaryPredicate>
+{
+};
+
+template <typename _BinaryPredicate>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(
+    oneapi::dpl::__internal::__parallel_reduce_by_segment_fallback_fn2, _BinaryPredicate)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_BinaryPredicate>
+{
+};
+
+template <typename _Op, typename _It1ValueT, typename _It2ValueTRef>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(
+    oneapi::dpl::__internal::__pattern_adjacent_difference_op_caller_fn, _Op, _It1ValueT, _It2ValueTRef)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_Op, _It1ValueT, _It2ValueTRef>
+{
+};
+
+namespace oneapi::dpl::__internal::__ranges
+{
+
+template <typename _Tp>
+struct __pattern_search_n_fn;
+
+} // namespace oneapi::dpl::__internal::__ranges
+
+template <typename _Tp>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__internal::__ranges::__pattern_search_n_fn, _Tp)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_Tp>
+{
+};
+
+namespace oneapi::dpl::experimental::ranges::__internal
+{
+
+template <typename _UnaryOperation>
+struct __transform_fn;
+
+template <typename _BinaryOperation>
+struct __transform_fn2;
+
+} // namespace oneapi::dpl::experimental::ranges::__internal
+
+template <typename _UnaryOperation>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::experimental::ranges::__internal::__transform_fn,
+                                                       _UnaryOperation)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_UnaryOperation>
+{
+};
+
+template <typename _BinaryOperation>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::experimental::ranges::__internal::__transform_fn2,
+                                                       _BinaryOperation)>
+    : oneapi::dpl::__internal::__are_all_device_copyable<_BinaryOperation>
+{
+};
+
 namespace oneapi::dpl::__par_backend_hetero
 {
 
@@ -263,7 +444,7 @@ struct __write_to_id_if_else;
 template <typename _BinaryPred>
 struct __write_red_by_seg;
 
-template <typename _ExecutionPolicy, typename _Pred>
+template <typename _Pred>
 struct __early_exit_find_or;
 
 template <typename _Range, typename _Compare>
@@ -342,9 +523,8 @@ struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__par_backen
 {
 };
 
-template <typename _ExecutionPolicy, typename _Pred>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__par_backend_hetero::__early_exit_find_or,
-                                                       _ExecutionPolicy, _Pred)>
+template <typename _Pred>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__par_backend_hetero::__early_exit_find_or, _Pred)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Pred>
 {
 };
@@ -365,41 +545,34 @@ struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::__par_backen
 namespace oneapi::dpl::unseq_backend
 {
 
-template <typename _ExecutionPolicy, typename _F>
+template <typename _F>
 struct walk_n;
 
-template <typename _ExecutionPolicy, typename _F, typename _Range>
-struct walk1_vector_or_scalar;
+template <typename _F>
+struct walk_n_vectors_or_scalars;
 
-template <typename _ExecutionPolicy, typename _F, typename _Range1, typename _Range2>
-struct walk2_vectors_or_scalars;
-
-template <typename _ExecutionPolicy, typename _F, typename _Range1, typename _Range2, typename _Range3>
-struct walk3_vectors_or_scalars;
-
-template <typename _ExecutionPolicy, typename _F, typename _Range1, typename _Range2>
+template <typename _F>
 struct walk_adjacent_difference;
 
-template <typename _ExecutionPolicy, typename _Operation1, typename _Operation2, typename _Tp, typename _Commutative,
-          std::uint8_t _VecSize>
+template <typename _Operation1, typename _Operation2, typename _Tp, typename _Commutative, std::uint8_t _VecSize>
 struct transform_reduce;
 
-template <typename _ExecutionPolicy, typename _BinaryOperation1, typename _Tp>
+template <typename _BinaryOperation1, typename _Tp>
 struct reduce_over_group;
 
-template <typename _ExecutionPolicy, typename _Pred>
+template <typename _Pred>
 struct single_match_pred_by_idx;
 
-template <typename _ExecutionPolicy, typename _Pred>
+template <typename _Pred>
 struct single_match_pred;
 
-template <typename _ExecutionPolicy, typename _Pred>
+template <typename _Pred>
 struct multiple_match_pred;
 
-template <typename _ExecutionPolicy, typename _Pred, typename _Tp, typename _Size>
+template <typename _Pred, typename _Tp, typename _Size>
 struct n_elem_match_pred;
 
-template <typename _ExecutionPolicy, typename _Pred>
+template <typename _Pred>
 struct first_match_pred;
 
 template <typename _Pred, typename _Tp>
@@ -417,101 +590,80 @@ struct __global_scan_functor;
 template <typename _InitType>
 struct __init_value;
 
-template <typename _Inclusive, typename _ExecutionPolicy, typename _BinaryOperation, typename _UnaryOp,
-          typename _WgAssigner, typename _GlobalAssigner, typename _DataAccessor, typename _InitType>
+template <typename _Inclusive, typename _BinaryOperation, typename _UnaryOp, typename _WgAssigner,
+          typename _GlobalAssigner, typename _DataAccessor, typename _InitType>
 struct __scan;
 
-template <typename _ExecutionPolicy, typename _Compare, typename _Size1, typename _Size2>
+template <typename _Compare, typename _Size1, typename _Size2>
 struct __brick_includes;
 
-template <typename _ExecutionPolicy, typename _Compare, typename _Size1, typename _Size2, typename _IsOpDifference>
+template <typename _Compare, typename _Size1, typename _Size2, typename _IsOpDifference>
 class __brick_set_op;
 
-template <typename _BinaryOperator, typename _Size, typename _Range>
+template <typename _BinaryOperator, typename _Size>
 struct __brick_reduce_idx;
 
 } // namespace oneapi::dpl::unseq_backend
 
-template <typename _ExecutionPolicy, typename _F>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk_n, _ExecutionPolicy, _F)>
+template <typename _F>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk_n, _F)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_F>
 {
 };
 
-template <typename _ExecutionPolicy, typename _F, typename _Range>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk1_vector_or_scalar,
-                                                       _ExecutionPolicy, _F, _Range)>
+template <typename _F>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk_n_vectors_or_scalars, _F)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_F>
 {
 };
 
-template <typename _ExecutionPolicy, typename _F, typename _Range1, typename _Range2>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk2_vectors_or_scalars,
-                                                       _ExecutionPolicy, _F, _Range1, _Range2)>
+template <typename _F>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk_adjacent_difference, _F)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_F>
 {
 };
 
-template <typename _ExecutionPolicy, typename _F, typename _Range1, typename _Range2, typename _Range3>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk3_vectors_or_scalars,
-                                                       _ExecutionPolicy, _F, _Range1, _Range2, _Range3)>
-    : oneapi::dpl::__internal::__are_all_device_copyable<_F>
-{
-};
-
-template <typename _ExecutionPolicy, typename _F, typename _Range1, typename _Range2>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::walk_adjacent_difference,
-                                                       _ExecutionPolicy, _F, _Range1, _Range2)>
-    : oneapi::dpl::__internal::__are_all_device_copyable<_F>
-{
-};
-
-template <typename _ExecutionPolicy, typename _Operation1, typename _Operation2, typename _Tp, typename _Commutative,
-          std::uint8_t _VecSize>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::transform_reduce, _ExecutionPolicy,
-                                                       _Operation1, _Operation2, _Tp, _Commutative, _VecSize)>
+template <typename _Operation1, typename _Operation2, typename _Tp, typename _Commutative, std::uint8_t _VecSize>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::transform_reduce, _Operation1,
+                                                       _Operation2, _Tp, _Commutative, _VecSize)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Operation1, _Operation2, _Tp>
 {
 };
 
-template <typename _ExecutionPolicy, typename _BinaryOperation1, typename _Tp>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::reduce_over_group, _ExecutionPolicy,
-                                                       _BinaryOperation1, _Tp)>
+template <typename _BinaryOperation1, typename _Tp>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::reduce_over_group, _BinaryOperation1,
+                                                       _Tp)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_BinaryOperation1, _Tp>
 {
 };
 
-template <typename _ExecutionPolicy, typename _Pred>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::single_match_pred_by_idx,
-                                                       _ExecutionPolicy, _Pred)>
+template <typename _Pred>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::single_match_pred_by_idx, _Pred)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Pred>
 {
 };
 
-template <typename _ExecutionPolicy, typename _Pred>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::single_match_pred, _ExecutionPolicy,
-                                                       _Pred)>
+template <typename _Pred>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::single_match_pred, _Pred)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Pred>
 {
 };
 
-template <typename _ExecutionPolicy, typename _Pred>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::multiple_match_pred,
-                                                       _ExecutionPolicy, _Pred)>
+template <typename _Pred>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::multiple_match_pred, _Pred)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Pred>
 {
 };
 
-template <typename _ExecutionPolicy, typename _Pred, typename _Tp, typename _Size>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::n_elem_match_pred, _ExecutionPolicy,
-                                                       _Pred, _Tp, _Size)>
+template <typename _Pred, typename _Tp, typename _Size>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::n_elem_match_pred, _Pred, _Tp,
+                                                       _Size)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Pred, _Tp, _Size>
 {
 };
 
-template <typename _ExecutionPolicy, typename _Pred>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::first_match_pred, _ExecutionPolicy,
-                                                       _Pred)>
+template <typename _Pred>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::first_match_pred, _Pred)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Pred>
 {
 };
@@ -549,33 +701,33 @@ struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backen
 {
 };
 
-template <typename _Inclusive, typename _ExecutionPolicy, typename _BinaryOperation, typename _UnaryOp,
-          typename _WgAssigner, typename _GlobalAssigner, typename _DataAccessor, typename _InitType>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::__scan, _Inclusive, _ExecutionPolicy,
-                                                       _BinaryOperation, _UnaryOp, _WgAssigner, _GlobalAssigner,
-                                                       _DataAccessor, _InitType)>
+template <typename _Inclusive, typename _BinaryOperation, typename _UnaryOp, typename _WgAssigner,
+          typename _GlobalAssigner, typename _DataAccessor, typename _InitType>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::__scan, _Inclusive, _BinaryOperation,
+                                                       _UnaryOp, _WgAssigner, _GlobalAssigner, _DataAccessor,
+                                                       _InitType)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_BinaryOperation, _UnaryOp, _WgAssigner, _GlobalAssigner,
                                                          _DataAccessor, _InitType>
 {
 };
 
-template <typename _ExecutionPolicy, typename _Compare, typename _Size1, typename _Size2>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::__brick_includes, _ExecutionPolicy,
-                                                       _Compare, _Size1, _Size2)>
+template <typename _Compare, typename _Size1, typename _Size2>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::__brick_includes, _Compare, _Size1,
+                                                       _Size2)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Compare, _Size1, _Size2>
 {
 };
 
-template <typename _ExecutionPolicy, typename _Compare, typename _Size1, typename _Size2, typename _IsOpDifference>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::__brick_set_op, _ExecutionPolicy,
-                                                       _Compare, _Size1, _Size2, _IsOpDifference)>
+template <typename _Compare, typename _Size1, typename _Size2, typename _IsOpDifference>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::__brick_set_op, _Compare, _Size1,
+                                                       _Size2, _IsOpDifference)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_Compare, _Size1, _Size2>
 {
 };
 
-template <typename _BinaryOperator, typename _Size, typename _Range>
+template <typename _BinaryOperator, typename _Size>
 struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::unseq_backend::__brick_reduce_idx, _BinaryOperator,
-                                                       _Size, _Range)>
+                                                       _Size)>
     : oneapi::dpl::__internal::__are_all_device_copyable<_BinaryOperator, _Size>
 {
 };
@@ -585,7 +737,7 @@ namespace oneapi::dpl::internal
 
 enum class search_algorithm;
 
-template <typename Comp, typename T, typename _Range, search_algorithm func>
+template <typename Comp, typename T, search_algorithm func>
 struct __custom_brick;
 
 template <typename T, typename Predicate>
@@ -605,8 +757,8 @@ class transform_if_stencil_fun;
 
 } // namespace oneapi::dpl::internal
 
-template <typename Comp, typename T, typename _Range, oneapi::dpl::internal::search_algorithm func>
-struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::internal::__custom_brick, Comp, T, _Range, func)>
+template <typename Comp, typename T, oneapi::dpl::internal::search_algorithm func>
+struct sycl::is_device_copyable<_ONEDPL_SPECIALIZE_FOR(oneapi::dpl::internal::__custom_brick, Comp, T, func)>
     : oneapi::dpl::__internal::__are_all_device_copyable<Comp, T>
 {
 };
